@@ -1,7 +1,7 @@
 /*
- *  This file is part of Poedit (http://poedit.net)
+ *  This file is part of Poedit (https://poedit.net)
  *
- *  Copyright (C) 2015-2016 Vaclav Slavik
+ *  Copyright (C) 2015-2017 Vaclav Slavik
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a
  *  copy of this software and associated documentation files (the "Software"),
@@ -81,7 +81,13 @@ void urlencoded_data::add_value(const std::string& name, const std::string& valu
 }
 
 
-std::string http_client::url_encode(const std::string& s)
+json_data::json_data(const json& data)
+{
+    m_body = data.dump();
+}
+
+
+std::string http_client::url_encode(const std::string& s, int flags)
 {
     std::ostringstream escaped;
     escaped.fill('0');
@@ -96,7 +102,7 @@ std::string http_client::url_encode(const std::string& s)
         {
             escaped << c;
         }
-        else if (c == ' ')
+        else if (c == ' ' && !(flags & encode_no_plus))
         {
             escaped << '+';
         }
@@ -109,7 +115,7 @@ std::string http_client::url_encode(const std::string& s)
     return escaped.str();
 }
 
-std::string http_client::url_encode(const std::wstring& s)
+std::string http_client::url_encode(const std::wstring& s, int flags)
 {
-    return url_encode(str::to_utf8(s));
+    return url_encode(str::to_utf8(s), flags);
 }
