@@ -1,7 +1,7 @@
 /*
  *  This file is part of Poedit (https://poedit.net)
  *
- *  Copyright (C) 2004-2016 Vaclav Slavik
+ *  Copyright (C) 2004-2017 Vaclav Slavik
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a
  *  copy of this software and associated documentation files (the "Software"),
@@ -32,6 +32,7 @@
 #include "icons.h"
 #include "edapp.h"
 #include "hidpi.h"
+#include "utility.h"
 
 #ifndef __WXOSX__
 
@@ -61,12 +62,14 @@ wxString GetGnomeStockId(const wxString& id)
 // Check if a given icon needs mirroring in right-to-left locales:
 bool ShouldBeMirorredInRTL(const wxArtID& id, const wxArtClient& client)
 {
+    // Silence warning about unused parameter in some of the builds
+    (void)client;
+
     static std::set<wxString> s_directional = {
         "ContributeOn",
         "poedit-status-comment",
         "follow-link",
-        "sidebar",
-        "sidebar-disabled"
+        "sidebar"
     };
 
     bool mirror = s_directional.find(id) != s_directional.end();
@@ -82,20 +85,25 @@ bool ShouldBeMirorredInRTL(const wxArtID& id, const wxArtClient& client)
 
 } // anonymous namespace
 
-wxBitmap PoeditArtProvider::CreateBitmap(const wxArtID& id,
+wxBitmap PoeditArtProvider::CreateBitmap(const wxArtID& id_,
                                          const wxArtClient& client,
                                          const wxSize& size)
 {
+    wxLogTrace("poedit.icons", "getting icon '%s'", id_.c_str());
+
+    wxArtID id(id_);
+    const bool disabledVariant = id.Contains("@disabled");
+    if (disabledVariant)
+        id.Replace("@disabled", "");
+
     // Silence warning about unused parameter in some of the builds
     (void)client;
     (void)size;
 
-    // Note: On Unix, this code is only called as last resolt, if standard
+    // Note: On Unix, this code is only called as last resort, if standard
     //       theme provider (that uses current icon theme and files from
     //       /usr/share/icons/<theme>) didn't find any matching icon.
 
-    wxLogTrace("poedit.icons", "getting icon '%s'", id.c_str());
-
 #ifdef __WXGTK20__
     // try legacy GNOME icons from standard theme:
     wxString gnomeId = GetGnomeStockId(id);
@@ -121,14 +129,35 @@ wxBitmap PoeditArtProvider::CreateBitmap(const wxArtID& id,
         return wxNullBitmap;
     }
 
-    bool mirror = false;
-    if (wxTheApp->GetLayoutDirection() == wxLayout_RightToLeft)
-        mirror = ShouldBeMirorredInRTL(id, client);
-
     wxString icon;
-    icon.Printf("%s/%s", iconsdir.c_str(), id.c_str());
-    wxLogTrace("poedit.icons", "loading from %s", icon.c_str());
-    return LoadScaledBitmap(icon, mirror);
+    icon.Printf("%s/%s", iconsdir, id);
+    wxLogTrace("poedit.icons", "loading from %s", icon);
+    wxImage img = LoadScaledBitmap(icon);
+    if (!img.IsOk())
+    {
+        wxLogTrace("poedit.icons", "failed to load icon '%s'", id);
+        return wxNullBitmap;
+    }
+
+    if (disabledVariant)
+        img = img.ConvertToDisabled();
+
+    if (wxTheApp->GetLayoutDirection() == wxLayout_RightToLeft && ShouldBeMirorredInRTL(id, client))
+    {
+        img = img.Mirror();
+    }
+
+#ifdef __WXMSW__
+    if (IsWindows10OrGreater())
+    {
+        const int padding = PX(1);
+        auto sz = img.GetSize();
+        sz.IncBy(padding * 2);
+        img.Resize(sz, wxPoint(padding, padding));
+    }
+#endif // __WXMSW__
+
+    return wxBitmap(img);
 }
 
 #endif // !__WXOSX__
