@@ -1,7 +1,7 @@
 /*
- *  This file is part of Poedit (http://poedit.net)
+ *  This file is part of Poedit (https://poedit.net)
  *
- *  Copyright (C) 2001-2016 Vaclav Slavik
+ *  Copyright (C) 2001-2017 Vaclav Slavik
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a
  *  copy of this software and associated documentation files (the "Software"),
@@ -46,7 +46,12 @@
 #include <wx/windowptr.h>
 #include <wx/splitter.h>
 
+#ifdef __WXMSW__
+#include <wx/msw/uxtheme.h>
+#endif
+
 #include "catalog.h"
+#include "cat_update.h"
 #include "edapp.h"
 #include "edframe.h"
 #include "hidpi.h"
@@ -85,8 +90,20 @@ ManagerFrame::ManagerFrame() :
 
     ms_instance = this;
 
-    wxXmlResource::Get()->LoadToolBar(this, "manager_toolbar");
-    wxXmlResource::Get()->LoadMenuBar(this, "manager_menu");
+    auto tb = wxXmlResource::Get()->LoadToolBar(this, "manager_toolbar");
+    (void)tb;
+#ifdef __WXMSW__
+    // De-uglify the toolbar a bit on Windows 10:
+    if (IsWindows10OrGreater())
+    {
+        const wxUxThemeEngine* theme = wxUxThemeEngine::GetIfActive();
+        if (theme)
+        {
+            wxUxThemeHandle hTheme(tb, L"ExplorerMenu::Toolbar");
+            tb->SetBackgroundColour(wxRGBToColour(theme->GetThemeSysColor(hTheme, COLOR_WINDOW)));
+        }
+    }
+#endif
 
     wxPanel *panel = wxXmlResource::Get()->LoadPanel(this, "manager_panel");
 
@@ -252,8 +269,8 @@ void ManagerFrame::UpdateListCat(int id)
     m_listCat->InsertColumn(0, _("Catalog"));
     m_listCat->InsertColumn(1, _("Total"));
     m_listCat->InsertColumn(2, _("Untrans"));
-    m_listCat->InsertColumn(3, _("Fuzzy"));
-    m_listCat->InsertColumn(4, _("Bad Tokens"));
+    m_listCat->InsertColumn(3, _("Needs Work"));
+    m_listCat->InsertColumn(4, _("Errors"));
     m_listCat->InsertColumn(5, _("Last modified"));
 
     // FIXME: this is time-consuming, it should be done in parallel on
@@ -447,7 +464,7 @@ void ManagerFrame::OnUpdateProject(wxCommandEvent&)
         {
             // FIXME: there should be only one progress bar for _all_
             //        catalogs, it shouldn't restart on next catalog
-            ProgressInfo pinfo(this, _("Updating catalog"));
+            //ProgressInfo pinfo(this, _("Updating catalog"));
 
             wxString f = m_catalogs[i];
             PoeditFrame *fr = PoeditFrame::Find(f);
@@ -457,12 +474,14 @@ void ManagerFrame::OnUpdateProject(wxCommandEvent&)
             }
             else
             {
-                Catalog cat(f);
+                auto cat = std::make_shared<Catalog>(f);
                 UpdateResultReason reason;
-                cat.Update(&pinfo, /*summary=*/false, reason);
-                int validation_errors = 0;
-                Catalog::CompilationStatus mo_status;
-                cat.Save(f, false, validation_errors, mo_status);
+                if (PerformUpdateFromSources(this, cat, reason, Update_DontShowSummary))
+                {
+                    int validation_errors = 0;
+                    Catalog::CompilationStatus mo_status;
+                    cat->Save(f, false, validation_errors, mo_status);
+                }
             }
          }
 
