@@ -1,7 +1,7 @@
 /*
  *  This file is part of Poedit (https://poedit.net)
  *
- *  Copyright (C) 2000-2016 Vaclav Slavik
+ *  Copyright (C) 2000-2017 Vaclav Slavik
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a
  *  copy of this software and associated documentation files (the "Software"),
@@ -37,6 +37,7 @@
 class WXDLLIMPEXP_FWD_ADV wxEditableListBox;
 class WXDLLIMPEXP_FWD_CORE wxTextCtrl;
 class WXDLLIMPEXP_FWD_CORE wxRadioButton;
+class WXDLLIMPEXP_FWD_CORE wxCheckBox;
 class WXDLLIMPEXP_FWD_CORE wxComboBox;
 
 /// Dialog setting various catalog parameters.
@@ -44,6 +45,7 @@ class PropertiesDialog : public wxDialog
 {
     public:
         PropertiesDialog(wxWindow *parent, CatalogPtr cat, bool fileExistsOnDisk, int initialPage = 0);
+        ~PropertiesDialog();
 
         /// Reads data from the catalog and fill dialog's controls.
         void TransferTo(const CatalogPtr& cat);
@@ -60,6 +62,7 @@ class PropertiesDialog : public wxDialog
         void OnLanguageValueChanged(const wxString& langstr);
         void OnPluralFormsDefault(wxCommandEvent& event);
         void OnPluralFormsCustom(wxCommandEvent& event);
+        void OnGettextSettings(wxCommandEvent& event);
 
         struct PathsData;
         class BasePathCtrl;
@@ -67,7 +70,10 @@ class PropertiesDialog : public wxDialog
         class SourcePathsList;
         class ExcludedPathsList;
 
-        wxTextCtrl *m_team, *m_teamEmail, *m_project;
+        struct GettextSettings;
+        class GettextSettingsDialog;
+
+        wxTextCtrl *m_team, *m_project;
         LanguageCtrl *m_language;
         wxComboBox *m_charset, *m_sourceCodeCharset;
         wxRadioButton *m_pluralFormsDefault, *m_pluralFormsCustom;
@@ -76,8 +82,9 @@ class PropertiesDialog : public wxDialog
         std::shared_ptr<PathsData> m_pathsData;
         PathsList *m_paths, *m_excludedPaths;
         wxEditableListBox *m_keywords;
+        wxCheckBox *m_defaultKeywords;
         wxString m_rememberedPluralForm;
-
+        std::shared_ptr<GettextSettings> m_gettextSettings;
         bool m_hasLang;
         int m_validatedPlural, m_validatedLang;
 };
