@@ -118,7 +118,7 @@ inline std::wstring to_wstring(NSString *str)
 #endif // Objective-C++
 
 
-// ICU conversions; only included them if ICU is included
+// ICU conversions; only include them if ICU is included
 #ifdef UNISTR_H
 
 /**
@@ -159,25 +159,6 @@ inline icu::UnicodeString to_icu(const std::wstring& str)
 #endif
 }
 
-/**
-    Create buffer with raw UChar* string.
-
-    Notice that the resulting string is only valid for the input's lifetime.
- */
-inline wxScopedCharTypeBuffer<UChar> to_icu_raw(const wxString& str)
-{
-    static_assert(U_SIZEOF_UCHAR == 2, "unexpected UChar size");
-#if SIZEOF_WCHAR_T == 2
-    // read-only aliasing ctor, doesn't copy data
-    return wxScopedCharTypeBuffer<UChar>::CreateNonOwned((const UChar*)str.wx_str(), str.length());
-#else
-    auto buf = wxMBConvUTF16().cWC2MB(str.wc_str());
-    auto len = buf.length();
-    return wxCharTypeBuffer<UChar>::CreateOwned((UChar*)buf.release(), len);
-#endif
-}
-
-
 /// Create wxString from icu::UnicodeString, making a copy.
 inline wxString to_wx(const icu::UnicodeString& str)
 {
@@ -196,6 +177,30 @@ inline std::wstring to_wstring(const icu::UnicodeString& str)
 
 #endif // UNISTR_H
 
+// Low-level ICU conversions:
+#ifdef U_SIZEOF_UCHAR
+
+/**
+    Create buffer with raw UChar* string.
+
+    Notice that the resulting string is only valid for the input's lifetime.
+ */
+inline wxScopedCharTypeBuffer<wxChar16> to_icu_raw(const wxString& str)
+{
+    static_assert(U_SIZEOF_UCHAR == 2, "unexpected UChar size");
+#if SIZEOF_WCHAR_T == 2
+    // read-only aliasing ctor, doesn't copy data
+    return wxScopedCharTypeBuffer<UChar>::CreateNonOwned((const UChar*)str.wx_str(), str.length());
+#else
+    auto buf = wxMBConvUTF16().cWC2MB(str.wc_str());
+    auto len = buf.length();
+    return wxCharTypeBuffer<wxChar16>::CreateOwned((wxChar16*)buf.release(), len);
+#endif
+}
+
+#endif // U_SIZEOF_UCHAR
+
+
 } // namespace str
 
 #endif // Poedit_str_helpers_h
