@@ -1,7 +1,7 @@
 /*
- *  This file is part of Poedit (http://poedit.net)
+ *  This file is part of Poedit (https://poedit.net)
  *
- *  Copyright (C) 2013-2016 Vaclav Slavik
+ *  Copyright (C) 2013-2017 Vaclav Slavik
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a
  *  copy of this software and associated documentation files (the "Software"),
@@ -553,7 +553,7 @@ public:
             return;
 
         // ignore translations with errors in them
-        if (item->GetValidity() == CatalogItem::Val_Invalid)
+        if (item->HasError())
             return;
 
         // can't handle plurals yet (TODO?)
@@ -669,19 +669,17 @@ SuggestionsList TranslationMemory::Search(const Language& srclang,
     return m_impl->Search(srclang, lang, source);
 }
 
-void TranslationMemory::SuggestTranslation(const Language& srclang,
-                                           const Language& lang,
-                                           const std::wstring& source,
-                                           success_func_type onSuccess,
-                                           error_func_type onError)
+dispatch::future<SuggestionsList> TranslationMemory::SuggestTranslation(const Language& srclang,
+                                                                        const Language& lang,
+                                                                        const std::wstring& source)
 {
     try
     {
-        onSuccess(Search(srclang, lang, source));
+        return dispatch::make_ready_future(Search(srclang, lang, source));
     }
     catch (...)
     {
-        onError(std::current_exception());
+        return dispatch::make_exceptional_future_from_current<SuggestionsList>();
     }
 }
 
