@@ -1,7 +1,7 @@
 /*
  *  This file is part of Poedit (https://poedit.net)
  *
- *  Copyright (C) 2013-2016 Vaclav Slavik
+ *  Copyright (C) 2013-2017 Vaclav Slavik
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a
  *  copy of this software and associated documentation files (the "Software"),
@@ -64,11 +64,9 @@ public:
                            const std::wstring& source);
 
     /// SuggestionsBackend API implementation:
-    void SuggestTranslation(const Language& srclang,
-                            const Language& lang,
-                            const std::wstring& source,
-                            success_func_type onSuccess,
-                            error_func_type onError) override;
+    dispatch::future<SuggestionsList> SuggestTranslation(const Language& srclang,
+                                                         const Language& lang,
+                                                         const std::wstring& source) override;
 
     /**
         Performs updates to the translation memory.
