@@ -56,8 +56,10 @@ class ActionButton : public wxWindow
 {
 public:
     ActionButton(wxWindow *parent, wxWindowID winid, const wxString& label, const wxString& note)
-        : wxWindow(parent, wxID_ANY, wxDefaultPosition, wxSize(500, 65))
+        : wxWindow(parent, wxID_ANY)
     {
+        SetMinSize(wxSize(500, 65));
+
         m_button = new wxButton(this, winid, "");
         auto sizer = new wxBoxSizer(wxHORIZONTAL);
         sizer->Add(m_button, wxSizerFlags(1).Expand());
@@ -269,7 +271,7 @@ EmptyPOScreenPanel::EmptyPOScreenPanel(PoeditFrame *parent)
     header->SetForegroundColour(m_clrHeader);
     sizer->Add(header, wxSizerFlags().Center().PXBorderAll());
 
-    auto explain = new wxStaticText(this, wxID_ANY, _("Translatable entries aren't added manually in the Gettext system, but are automatically extracted\nfrom source code. This way, they stay up to date and accurate.\nTranslators typically use PO template files (POTs) prepared for them by the developer."));
+    auto explain = new wxStaticText(this, wxID_ANY, _(L"Translatable entries aren’t added manually in the Gettext system, but are automatically extracted\nfrom source code. This way, they stay up to date and accurate.\nTranslators typically use PO template files (POTs) prepared for them by the developer."));
     explain->SetFont(m_fntNorm);
     explain->SetForegroundColour(m_clrNorm);
     sizer->Add(explain, wxSizerFlags());
